<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | Article_ex Plugin 1.0.0 for Geeklog - The Ultimate Weblog                 |
// +---------------------------------------------------------------------------+
// | public_html/article_ex/article_ex.php                                     |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2008 Yoshinori Tahara - dengen                              |
// +---------------------------------------------------------------------------+
// | article.php                                                               |
// |                                                                           |
// | Shows articles in various formats.                                        |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2000-2006 by the following authors:                         |
// |                                                                           |
// | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
// |          Jason Whittenburg - jwhitten AT securitygeeks DOT com            |
// |          Dirk Haun         - dirk AT haun-online DOT de                   |
// |          Vincent Furia     - vinny01 AT users DOT sourceforge DOT net     |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//
// $Id: article_ex.php,v 1.84 2006/12/02 16:39:14 dhaun Exp $

/**
* This page is responsible for showing a single article in different modes which
* may, or may not, include the comments attached
*
* @author   Jason Whittenburg
* @author   Tony Bibbbs <tony@tonybibbs.com>
* @author   Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
*/

/**
* article_ex.php は article.php をハックしたものです。
* article.php に comment.php をくっつけたようなものです。
* hacked by dengen - Yoshinori Tahara
*
* 強化ポイント
* 記事表示中にコメント投稿ができる。
* ゲストユーザがコメントにユーザ名、メールアドレス、ホームページURLを付けて投稿できる。
*
*/

/**
* Geeklog common function library
*/
require_once ('./../lib-common.php');
require_once ($_CONF['path_system'] . 'lib-story.php');
if ($_CONF['trackback_enabled']) {
    require_once ($_CONF['path_system'] . 'lib-trackback.php');
}

// lib-comment-ex.php は lib-comment.php の カスタマイズ版です。
// lib-comment-ex.php は article_ex.php だけが使用します。
require_once( $_CONF['path'] . 'plugins/article_ex/lib-comment-ex.php' );


// Uncomment the line below if you need to debug the HTTP variables being passed
// to the script.  This will sometimes cause errors but it will allow you to see
// the data being passed in a POST operation

// echo COM_debug($_POST);

/**
* Set cookie
*/
function AEX_setcookie( $name, $value ) {
    global $_CONF, $LANG_CHARSET;
    
    if ( isset( $LANG_CHARSET ) ) {
        $encoding = $LANG_CHARSET;
    } else if ( isset( $_CONF['default_charset'] ) ) {
        $encoding = $_CONF['default_charset'];
    } else {
        $encoding = 'UTF-8';
    }
    setcookie (
        $name, htmlspecialchars( $value, ENT_QUOTES, $encoding ),
        time() + 31536000,
        $_CONF['cookie_path'], $_CONF['cookiedomain'], $_CONF['cookiesecure']
    );
}


/**
 * Handles a comment submission
 *
 * @copyright Vincent Furia 2005
 * @author Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
 * @return string HTML (possibly a refresh)
 */
function AEX_handleSubmit($title, $sid, $pid, $type, $postmode, $uid, $username, $commentemail, $commenthomepage)
{
    global $_CONF, $_TABLES, $_USER, $LANG03;

    $display = '';

    $commentcode = DB_getItem ($_TABLES['stories'], 'commentcode',
                  "sid = '$sid'" . COM_getPermSQL('AND') . COM_getTopicSQL('AND'));
    if (!isset($commentcode) || $commentcode < 0) {
        return COM_refresh ($_CONF['site_url'] . '/index.php');
    }

    $ret = CMT_saveComment_ex ( strip_tags($title), $_POST['comment'],
           $sid, $pid, 'article', $postmode, $username, $commentemail, $commenthomepage);

    if ( $ret > 0 ) { // failure //FIXME: some failures should not return to comment form
        $display .= CMT_commentForm_ex ($title, $_POST['comment'],
                   $sid, $pid, $type, $LANG03[14], $postmode);
    } else { // success
        $comments = DB_count ($_TABLES['comments'], 'sid', $sid);
        DB_change ($_TABLES['stories'], 'comments', $comments, 'sid', $sid);
        COM_olderStuff (); // update comment count in Older Stories block
        
// added by dengen ---->
        if ($uid == 1) { // ゲストユーザの場合
            // Set cookie (username, email, homepage)
            AEX_setcookie( "comment_author", $username );
            AEX_setcookie( "comment_author_email", $commentemail );
            AEX_setcookie( "comment_author_homepage", $commenthomepage );
        }
// added by dengen ----<
        
        $display = COM_refresh (COM_buildUrl ($_CONF['site_url']
            . "/article.php?story=$sid"));
    }

    return $display;
}

/**
 * Hanldes a comment submission
 *
 * @copyright Vincent Furia 2005
 * @author Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
 * @return string HTML (possibly a refresh)
 */
function AEX_handleDelete($sid, $type)
{
    global $_CONF, $_TABLES;

    $display = '';

    $has_editPermissions = SEC_hasRights ('story.edit');
    $result = DB_query ("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon "
                      . "FROM {$_TABLES['stories']} WHERE sid = '$sid'");
    $A = DB_fetchArray ($result);

    if ($has_editPermissions && SEC_hasAccess ($A['owner_id'],
            $A['group_id'], $A['perm_owner'], $A['perm_group'],
            $A['perm_members'], $A['perm_anon']) == 3) {
        $cid = COM_applyFilter($_REQUEST['cid'], true);
        CMT_deleteComment_ex($cid, $sid, 'article');
        $comments = DB_count ($_TABLES['comments'], 'sid', $sid);
        DB_change ($_TABLES['stories'], 'comments', $comments, 'sid', $sid);
        $display .= COM_refresh (COM_buildUrl ($_CONF['site_url']
                 . "/article.php?story=$sid") . '#comments');
    } else {
        COM_errorLog ("User {$_USER['username']} (IP: {$_SERVER['REMOTE_ADDR']}) "
                    . "tried to illegally delete comment $cid from $type $sid");
        $display .= COM_refresh ($_CONF['site_url'] . '/index.php');
    }

    return $display;
}


// MAIN
$display = '';

$order = '';
$query = '';
$reply = '';
$mode  = '';

if (isset ($_POST['mode'])) {
    $story = COM_applyFilter ($_POST['story']);

// added by dengen ---->
    if (!empty ($_REQUEST['sid'])) {
        $story = COM_applyFilter ($_REQUEST['sid']);
    }
// added by dengen ----<

    $mode = COM_applyFilter ($_POST['mode']);
    if (isset ($_POST['order'])) {
        $order = COM_applyFilter ($_POST['order']); // "古い順" "新しい順"
    }
    if (isset ($_POST['query'])) {
        $query = COM_applyFilter ($_POST['query']);
    }
    if (isset ($_POST['reply'])) {
        $reply = COM_applyFilter ($_POST['reply']); // コメント投稿
    }
} else {
    COM_setArgNames (array ('story', 'mode'));
    $story = COM_applyFilter (COM_getArgument ('story')); // $story
    $mode = COM_applyFilter (COM_getArgument ('mode'));   // $mode

// added by dengen ---->
    if (!empty ($_REQUEST['sid'])) {
        $story = COM_applyFilter ($_REQUEST['sid']);
    }
// added by dengen ----<

    if (isset ($_GET['order'])) {
        $order = COM_applyFilter ($_GET['order']);
    }
    if (isset ($_GET['query'])) {
        $query = COM_applyFilter ($_GET['query']);
    }
    if (isset ($_GET['reply'])) {
        $reply = COM_applyFilter ($_GET['reply']);
    }
}

if (empty ($story)) {
    echo COM_refresh ($_CONF['site_url'] . '/index.php');
    exit();
}
if ((strcasecmp ($order, 'ASC') != 0) && (strcasecmp ($order, 'DESC') != 0)) {
    $order = '';
}

$result = DB_query("SELECT COUNT(*) AS count FROM {$_TABLES['stories']} WHERE sid = '$story'" . COM_getPermSql ('AND'));
$A = DB_fetchArray($result);
$sql = array();
if ($A['count'] > 0) {
    $sql['mysql'] = "SELECT STRAIGHT_JOIN s.*, UNIX_TIMESTAMP(s.date) AS day, "
     . "u.username, u.fullname, u.photo, u.email, t.topic, t.imageurl "
     . "FROM {$_TABLES['stories']} AS s, {$_TABLES['users']} AS u, {$_TABLES['topics']} AS t "
     . "WHERE (s.uid = u.uid) AND (s.tid = t.tid) AND (sid = '$story')";

    $sql['mssql'] = "SELECT STRAIGHT_JOIN s.sid, s.uid, s.draft_flag, s.tid, s.date, s.title, CAST(s.introtext AS text) AS introtext, CAST(s.bodytext AS text) AS bodytext, s.hits, s.numemails, s.comments, s.trackbacks, s.related, s.featured, s.show_topic_icon, s.commentcode, s.trackbackcode, s.statuscode, s.expire, s.postmode, s.frontpage, s.in_transit, s.owner_id, s.group_id, s.perm_owner, s.perm_group, s.perm_members, s.perm_anon, s.advanced_editor_mode, "
     . " UNIX_TIMESTAMP(s.date) AS day, "
     . "u.username, u.fullname, u.photo, u.email, t.topic, t.imageurl "
     . "FROM {$_TABLES['stories']} AS s, {$_TABLES['users']} AS u, {$_TABLES['topics']} AS t "
     . "WHERE (s.uid = u.uid) AND (s.tid = t.tid) AND (sid = '$story')";

    $result = DB_query ($sql);
    $A = DB_fetchArray ($result); // $A

    $access = SEC_hasAccess ($A['owner_id'], $A['group_id'],
            $A['perm_owner'], $A['perm_group'], $A['perm_members'],
            $A['perm_anon']);
    
    if (($access == 0) OR !SEC_hasTopicAccess ($A['tid']) OR
        (($A['draft_flag'] == 1) AND !SEC_hasRights ('story.edit'))) {
        
        $display .= COM_siteHeader ('menu', $LANG_ACCESS['accessdenied'])
                 . COM_startBlock ($LANG_ACCESS['accessdenied'], '',
                           COM_getBlockTemplate ('_msg_block', 'header'))
                 . $LANG_ACCESS['storydenialmsg']
                 . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'))
                 . COM_siteFooter ();
        
    } else {
    
        switch ($mode) {

        case 'print':
            if ($_CONF['hideprintericon'] == 0) {
                $story_template = new Template ($_CONF['path_layout'] . 'article');
                $story_template->set_file ('article', 'printable.thtml');
                $story_template->set_var ('page_title',
                        $_CONF['site_name'] . ': ' . stripslashes ($A['title'])); 
                $story_template->set_var ('story_title', stripslashes ($A['title']));
                if (empty ($LANG_CHARSET)) {
                    $charset = $_CONF['default_charset'];
                    if (empty( $charset)) {
                        $charset = 'iso-8859-1';
                    }
                } else {
                    $charset = $LANG_CHARSET;
                }
                header ('Content-Type: text/html; charset='. $charset);
                $curtime = COM_getUserDateTimeFormat ($A['day']);
                $story_template->set_var ('story_date', $curtime[0]);

                if ($_CONF['contributedbyline'] == 1) {
                    $story_template->set_var ('lang_contributedby', $LANG01[1]);
                    $authorname = COM_getDisplayName ($A['uid']);
                    $story_template->set_var ('author', $authorname);
                    $story_template->set_var ('story_author', $authorname);
                    $story_template->set_var ('story_author_username', $A['username']);
                }

                if ($A['postmode'] == 'plaintext') {
                    $A['introtext'] = nl2br ($A['introtext']);
                    $A['bodytext'] = nl2br ($A['bodytext']);
                }
                $story_template->set_var ('story_introtext',
                        PLG_replaceTags (stripslashes ($A['introtext'])));
                $story_template->set_var ('story_bodytext',
                        PLG_replaceTags (stripslashes ($A['bodytext'])));

                $story_template->set_var ('site_url', $_CONF['site_url']);
                $story_template->set_var ('layout_url', $_CONF['layout_url']);
                $story_template->set_var ('site_name', $_CONF['site_name']);
                $story_template->set_var ('site_slogan', $_CONF['site_slogan']);
                $story_template->set_var ('story_id', $A['sid']);
                $articleUrl = COM_buildUrl ($_CONF['site_url']
                                            . '/article.php?story=' . $A['sid']);
                if ($A['commentcode'] >= 0) {
                    $commentsUrl = $articleUrl . '#comments';
                    $comments = $A['comments'];
                    $numComments = COM_numberFormat ($comments);
                    $story_template->set_var ('story_comments', $numComments);
                    $story_template->set_var ('comments_url', $commentsUrl);
                    $story_template->set_var ('comments_text',
                            $numComments . ' ' . $LANG01[3]);
                    $story_template->set_var ('comments_count', $numComments);
                    $story_template->set_var ('lang_comments', $LANG01[3]);
                    $story_template->set_var ('comments_with_count',
                            sprintf ($LANG01[121], $numComments));

                    if ($comments > 0) {
                        $story_template->set_var ('start_comments_anchortag',
                                '<a href="' . $commentsUrl . '">');
                        $story_template->set_var ('end_comments_anchortag', '</a>');
                    }
                }
                $story_template->set_var ('lang_full_article', $LANG08[33]);
                $story_template->set_var ('article_url', $articleUrl);
                $story_template->parse ('output', 'article');
                $display = $story_template->finish ($story_template->get_var('output'));
            }
            break;
            
        default:
            // Set page title
            $pagetitle = stripslashes (str_replace ('$', '&#36;', $A['title']));

            $rdf = '';
            if ($A['trackbackcode'] == 0) {
                if ($_CONF['trackback_enabled']) {
                    $permalink = COM_buildUrl ($_CONF['site_url']
                                               . '/article.php?story=' . $story);
                    $trackbackurl = TRB_makeTrackbackUrl ($story);
                    $rdf = '<!--' . LB
                         . TRB_trackbackRdf ($permalink, $A['title'], $trackbackurl)
                         . LB . '-->' . LB;
                }
                if ($_CONF['pingback_enabled']) {
                    header ('X-Pingback: ' . $_CONF['site_url'] . '/pingback.php');
                }
            }
            $display .= COM_siteHeader ('menu', $pagetitle, $rdf);
            
            if (isset ($_GET['msg'])) {
                $display .= COM_showMessage (COM_applyFilter ($_GET['msg'], true));
            }

            DB_query ("UPDATE {$_TABLES['stories']} SET hits = hits + 1 WHERE (sid = '$story') AND (date <= NOW()) AND (draft_flag = 0)");

            // Display whats related

// changed by dengen 2007.12.28 ---->
//          $story_template = new Template($_CONF['path_layout'] . 'article');
// changed by dengen 2007.12.28 ----|
            $story_template = new Template($_AEX_CONF['path_templates']);
// changed by dengen 2007.12.28 ----<
            $story_template->set_file('article','article.thtml');

            $story_template->set_var('site_url', $_CONF['site_url']);
            $story_template->set_var('layout_url', $_CONF['layout_url']);
            $story_template->set_var('story_id', $story);
            $story_options = array ();
            if (($_CONF['hideemailicon'] == 0) && (!empty ($_USER['username']) ||
                    (($_CONF['loginrequired'] == 0) &&
                     ($_CONF['emailstoryloginrequired'] == 0)))) {
                $emailUrl = $_CONF['site_url'] . '/profiles.php?sid=' . $story
                          . '&amp;what=emailstory';
                $story_options[] = '<a href="' . $emailUrl . '">' . $LANG11[2]
                                 . '</a>';
                $story_template->set_var ('email_story_url', $emailUrl);
                $story_template->set_var ('lang_email_story', $LANG11[2]);
                $story_template->set_var ('lang_email_story_alt', $LANG01[64]);
            }
            $printUrl = COM_buildUrl ($_CONF['site_url']
                    . '/article.php?story=' . $story .  '&amp;mode=print');
            if ($_CONF['hideprintericon'] == 0) {
                $story_options[] = '<a href="' . $printUrl . '">' . $LANG11[3]
                                 . '</a>';
                $story_template->set_var ('print_story_url', $printUrl);
                $story_template->set_var ('lang_print_story', $LANG11[3]);
                $story_template->set_var ('lang_print_story_alt', $LANG01[65]);
            }
            if ($_CONF['pdf_enabled'] == 1) {
                $pdfUrl = $_CONF['site_url']
                        . '/pdfgenerator.php?pageType=2&amp;pageData='
                        . urlencode ($printUrl);
                $story_options[] = '<a href="' . $pdfUrl . '">' . $LANG11[5]
                                 . '</a>';
                $story_template->set_var ('pdf_story_url', $printUrl);
                $story_template->set_var ('lang_pdf_story', $LANG11[5]);
            }
            $related = STORY_whatsRelated ($A['related'], $A['uid'], $A['tid']);
            if (!empty ($related)) {
                $related = COM_startBlock ($LANG11[1], '',
                    COM_getBlockTemplate ('whats_related_block', 'header'))
                    . $related
                    . COM_endBlock (COM_getBlockTemplate ('whats_related_block',
                        'footer'));
            }
            if (count ($story_options) > 0) {
                $optionsblock = COM_startBlock ($LANG11[4], '',
                        COM_getBlockTemplate ('story_options_block', 'header'))
                    . COM_makeList ($story_options, 'list-story-options')
                    . COM_endBlock (COM_getBlockTemplate ('story_options_block',
                        'footer'));
            } else {
                $optionsblock = '';
            }
            $story_template->set_var ('whats_related', $related);
            $story_template->set_var ('story_options', $optionsblock);
            $story_template->set_var ('whats_related_story_options',
                                      $related . $optionsblock);

            $story_template->set_var ('formatted_article',
                                      STORY_renderArticle ($A, 'n', '', $query));

            // display comments or not?
            if ( (is_numeric($mode)) and ($_CONF['allow_page_breaks'] == 1) )
            {
                $story_page = $mode;
                $mode = '';
                if( $story_page <= 0 ) {
                    $story_page = 1;
                }
                $article_arr = explode( '[page_break]', $A['bodytext']);
                $conf = $_CONF['page_break_comments'];
                if  (
                     ($conf == 'all') or
                     ( ($conf =='first') and ($story_page == 1) ) or
                     ( ($conf == 'last') and (count($article_arr) == ($story_page)) )
                    ) {
                    $show_comments = true;
                } else {
                    $show_comments = false;
                }
            } else {
                $show_comments = true;
            }

            // Display the comments, if there are any ..
            if (($A['commentcode'] >= 0) and $show_comments) {
                $delete_option = (SEC_hasRights('story.edit') && ($access == 3)
                                 ? true : false);
                //require_once ( $_CONF['path_system'] . 'lib-comment-ex.php' );
                $story_template->set_var ('commentbar',
                        CMT_userComments_ex ($story, $A['title'], 'article',
                                          $order, $mode, 0, $page, false, $delete_option));
            }
            if ($_CONF['trackback_enabled'] && ($A['trackbackcode'] >= 0) &&
                    $show_comments) {
                if (SEC_hasRights ('story.ping')) {
                    if (($A['draft_flag'] == 0) && ($A['day'] < time ())) {
                        $url = $_CONF['site_admin_url']
                             . '/trackback.php?mode=sendall&amp;id=' . $A['sid'];
                        $story_template->set_var ('send_trackback_link', '<a href="'
                             . $url . '">' . $LANG_TRB['send_trackback'] . '</a>');
                        $story_template->set_var ('send_trackback_url', $url);
                        $story_template->set_var ('lang_send_trackback_text',
                                                  $LANG_TRB['send_trackback']);
                    }
                }

                $permalink = COM_buildUrl ($_CONF['site_url']
                                           . '/article.php?story=' . $story);
                $story_template->set_var ('trackback',
                        TRB_renderTrackbackComments ($story, 'article',
                                                     $A['title'], $permalink));
            } else {
                $story_template->set_var ('trackback', '');
            }

// comment.php からもってきて変更 by dengen ---->
            // $commentmode     : コメントに関する実行モード（article.php の 'mode' との競合を回避するため 'commentmode' へ変更）
            // $sid             : 記事のID
            // $pid             : 親コメントのID
            // $type            : コンテンツの種類（記事つまり'article'に限定）
            // $title           : 記事のタイトル
            // $uid             : ユーザのID 
            // $username        : コメントの投稿ユーザ名
            // $commentemail    : コメントの投稿ユーザのemailアドレス
            // $commenthomepage : コメントの投稿ユーザのホームページURL
            // $postmode        : コメントの投稿モード（'html' または 'plaintext'）
            // 
            if (!empty ($_REQUEST['commentmode'])) { // 実行モード
                $commentmode = COM_applyFilter ($_REQUEST['commentmode']);
            } else {
                $commentmode = $mode;
            }

            if (!empty ($_REQUEST['sid'])) { // 記事のID
                $sid = COM_applyFilter ($_REQUEST['sid']);
            } else {
                $sid = $A['sid'];
            }

            if (!empty ($_REQUEST['pid'])) { // 親コメントのID
                $pid = COM_applyFilter ($_REQUEST['pid'], true);
            } else {
                $pid = 0;
            }

            $type = 'article'; // コンテンツの種類

            if (!empty ($_REQUEST['title'])) { // 記事のタイトル
                $title = COM_applyFilter ($_REQUEST['title']);
            } else {
                $title = $A['title'];
            }

            if (!empty ($_REQUEST['uid'])) { // ユーザID
                $uid = COM_applyFilter ($_REQUEST['uid']);
            } else {
                if (empty ($_USER['uid'])) {
                    $uid = 1; // ゲストユーザ
                } else {
                    $uid = $_USER['uid'];
                }
            }

            if ($uid != 1) { // ユーザ名
                $username = DB_getItem ($_TABLES['users'], 'username', 'uid=' . $uid);
            } else if (!empty ($_REQUEST['username'])) { // ゲストユーザの場合
                $username = COM_applyFilter ($_REQUEST['username']);
            } else if ( isset ($_COOKIE['comment_author']) ) { // クッキーから取得
                $username = COM_applyFilter ($_COOKIE['comment_author']);
            } else {
                $username = '';
            }

            if ($uid != 1) { // メールアドレス
                $commentemail = '';
            } else if (!empty ($_REQUEST['commentemail'])) { // ゲストユーザの場合
                $commentemail = COM_applyFilter ($_REQUEST['commentemail']);
            } else if ( isset ($_COOKIE['comment_author_email']) ) { // クッキーから取得
                $commentemail = COM_applyFilter ($_COOKIE['comment_author_email']);
            } else {
                $commentemail = '';
            }

            if ($uid != 1) { // ホームページ
                $commenthomepage = '';
            } else if (!empty ($_REQUEST['commenthomepage'])) { // ゲストユーザの場合
                $commenthomepage = COM_applyFilter ($_REQUEST['commenthomepage']);
            } else if ( isset ($_COOKIE['comment_author_homepage']) ) { // クッキーから取得
                $commenthomepage = COM_applyFilter ($_COOKIE['comment_author_homepage']);
            } else {
                $commenthomepage = '';
            }

            if (isset ($_REQUEST['postmode'])) { // コメントの投稿モード
                $postmode = COM_applyFilter ($_REQUEST['postmode']);
            } else {
                $postmode = $_CONF['postmode'];
            }

            switch ($commentmode) {
            
            case $LANG03[14]: // Preview
                $story_template->set_var ('commenteditor',
                    CMT_commentForm_ex ($title, $_POST['comment'],
                                $sid, $pid, $type, $commentmode,
                                $postmode,
                                $mode, $username, $commentemail, $commenthomepage) );
                break;

            case $LANG03[11]: // Submit comment
                $display .= AEX_handleSubmit($title, $sid, $pid, $type, $postmode, 
                                             $uid, $username, $commentemail, $commenthomepage);
                break;

            case 'delete': // Delete comment
                $display .= AEX_handleDelete($sid, $type);
                break;

            default:
                if (!empty ($sid)) { 
                    if (empty ($title)) {
                        $title = DB_getItem ($_TABLES['stories'], 'title',
                                             "sid = '{$sid}'" . COM_getPermSQL('AND') . COM_getTopicSQL('AND'));
                        $title = str_replace ( '$', '&#36;', $title );
                        // CMT_commentForm_ex expects non-htmlspecial chars for title...
                        $title = str_replace ( '&amp;', '&', $title );
                        $title = str_replace ( '&quot;', '"', $title );
                        $title = str_replace ( '&lt;', '<', $title );
                        $title = str_replace ( '&gt;', '>', $title );
                    }
                    $story_template->set_var ('commenteditor',
                        CMT_commentForm_ex ($title, '', $sid, $pid, $type, $commentmode, $postmode,
                                    $articlemode, $username, $commentemail, $commenthomepage) );
                } else {
                    echo COM_refresh($_CONF['site_url'] . '/index.php');
                    exit();
                }
                break;
            }
            
// comment.php からもってきて変更 by dengen ----<

            $display .= $story_template->finish ($story_template->parse ('output', 'article'));
            $display .= COM_siteFooter ();
            break;
        }
    
    }
    
} else {
    $display .= COM_refresh($_CONF['site_url'] . '/index.php');
}

echo $display;

?>
